@@ -10,10 +10,15 @@ sub cli_abstract ($self) {
 
 sub cli_opt ($self) {
     return {
-        all      => { desc => 'status "new" + "open" + "resolved" + "closed"', default => 0 },
-        open     => { desc => 'status "new" + "open"',                         default => 0 },
-        resolved => { desc => 'status "resolved"',                             default => 0 },
-        closed   => { desc => 'status "closed"',                               default => 0 },
+        active    => { desc  => 'new, open, resolved, closed' },
+        new       => { desc  => 'status "new" + "open"' },
+        open      => { desc  => 'status "new" + "open"' },
+        resolved  => { desc  => 'status "resolved"' },
+        closed    => { desc  => 'status "closed"' },
+        hold      => { short => 'H', desc => 'status "on hold"' },
+        invalid   => { desc  => 'status "invalid"' },
+        duplicate => { desc  => 'status "duplicate"' },
+        wontfix   => { desc  => 'status "wonfix"' },
     };
 }
 
@@ -21,6 +26,7 @@ sub cli_arg ($self) {
     return [
         {   name => 'id',
             desc => 'issue ID',
+            isa  => 'PositiveInt',
             min  => 0,
         },
     ];
@@ -39,14 +45,24 @@ sub run ( $self, $opt, $arg ) {
             $opt->%*,
         );
 
-        $self->dist->build->issues->print_issues($issues);
+        if ( $arg->{id} && $opt->%* ) {
+
+            # issue status changed, show only issue header, without content
+            if ($issues) {
+                $self->dist->build->issues->print_issues( $issues, 0 );
+            }
+            else {
+                say 'Error update issue status';
+            }
+        }
+        else {
+            $self->dist->build->issues->print_issues( $issues, 1 );
+        }
     }
     else {
         say 'No issues';
     }
 
-    say q[];
-
     return;
 }
 
@@ -57,9 +73,9 @@ sub run ( $self, $opt, $arg ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 39                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 45, 48               │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 37, 42               │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │    2 │ 43, 52, 59           │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
