@@ -1,11 +1,9 @@
 package Pcore::Dist::CLI::Test;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::Dist::CLI];
 
-no Pcore;
-
 sub cli_abstract ($self) {
     return 'test your distribution';
 }
@@ -44,7 +42,7 @@ sub run ( $self, $args ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 35                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 33                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
