@@ -1,11 +1,11 @@
 package Pcore::Util::File::TempFile;
 
-use Pcore qw[-const];
+use Pcore -const;
 use base qw[IO::Handle IO::Seekable];
 use Fcntl qw[:DEFAULT];
-use Scalar::Util qw[refaddr];    ## no critic qw[Modules::ProhibitEvilModules]
+use Pcore::Util::Scalar qw[refaddr];
 
-use overload                     #
+use overload    #
   q[""] => sub {
     return $_[0]->path;
   },
@@ -21,8 +21,6 @@ const our $TMPL => [ 0 .. 9, 'a' .. 'z', 'A' .. 'Z' ];
 
 our @DEFERRED_UNLINK;
 
-no Pcore;
-
 END {
     for (@DEFERRED_UNLINK) {
         unlink or 1;
@@ -31,16 +29,16 @@ END {
 
 sub new ( $self, @ ) {
     my %args = (
-        base      => $PROC->{TEMP_DIR},
+        base      => $ENV->{TEMP_DIR},
         suffix    => q[],
-        tmpl      => 'temp-' . P->sys->pid . '-XXXXXXXX',
+        tmpl      => "temp-$$-XXXXXXXX",
         exclusive => 0,
         mode      => 'rw-------',
         umask     => undef,
-        crlf      => 0,                                     # undef - auto, 1 - on, 0 - off (for binary files)
+        crlf      => 0,                    # undef - auto, 1 - on, 0 - off (for binary files)
         binmode   => undef,
         autoflush => 1,
-        @_[ 1 .. $#_ ]
+        splice @_, 1,
     );
 
     $args{suffix} = q[.] . $args{suffix} if defined $args{suffix} && $args{suffix} ne q[] && substr( $args{suffix}, 0, 1 ) ne q[.];
@@ -62,7 +60,7 @@ sub new ( $self, @ ) {
 
     my $fh = P->file->get_fh( $args{base} . q[/] . $filename, $mode, %args );
 
-    *$fh->$* = [ P->path( $args{base} . q[/] . $filename )->realpath->to_string, P->sys->pid ];    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
+    *$fh->$* = [ P->path( $args{base} . q[/] . $filename )->realpath->to_string, $$ ];    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
     return bless $fh, $self;
 }
@@ -72,7 +70,7 @@ sub new ( $self, @ ) {
 sub DESTROY ($self) {
 
     # do not unlink files, created by others processes
-    return if $self->pid ne P->sys->pid;
+    return if $self->owner_pid ne $$;
 
     close $self or 1;
 
@@ -87,14 +85,14 @@ sub path ($self) {
     return *$self->$*->[0];
 }
 
-sub pid ($self) {
+sub owner_pid ($self) {
     return *$self->$*->[1];
 }
 
 sub TO_DUMP ( $self, $dumper, @ ) {
     my %args = (
         path => undef,
-        @_[ 2 .. $#_ ]
+        splice @_, 2,
     );
 
     my $res;
@@ -113,9 +111,7 @@ sub TO_DUMP ( $self, $dumper, @ ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 65, 87, 91           │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 33                   │ CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    │
+## │    3 │ 63, 85, 89           │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
